#line 1 "minilexer.c"

#line 3 "minilexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define miniyy_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer miniyy_create_buffer
#endif

#ifdef yy_delete_buffer
#define miniyy_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer miniyy_delete_buffer
#endif

#ifdef yy_scan_buffer
#define miniyy_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer miniyy_scan_buffer
#endif

#ifdef yy_scan_string
#define miniyy_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string miniyy_scan_string
#endif

#ifdef yy_scan_bytes
#define miniyy_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes miniyy_scan_bytes
#endif

#ifdef yy_init_buffer
#define miniyy_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer miniyy_init_buffer
#endif

#ifdef yy_flush_buffer
#define miniyy_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer miniyy_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define miniyy_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state miniyy_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define miniyy_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer miniyy_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define miniyypush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state miniyypush_buffer_state
#endif

#ifdef yypop_buffer_state
#define miniyypop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state miniyypop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define miniyyensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack miniyyensure_buffer_stack
#endif

#ifdef yylex
#define miniyylex_ALREADY_DEFINED
#else
#define yylex miniyylex
#endif

#ifdef yyrestart
#define miniyyrestart_ALREADY_DEFINED
#else
#define yyrestart miniyyrestart
#endif

#ifdef yylex_init
#define miniyylex_init_ALREADY_DEFINED
#else
#define yylex_init miniyylex_init
#endif

#ifdef yylex_init_extra
#define miniyylex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra miniyylex_init_extra
#endif

#ifdef yylex_destroy
#define miniyylex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy miniyylex_destroy
#endif

#ifdef yyget_debug
#define miniyyget_debug_ALREADY_DEFINED
#else
#define yyget_debug miniyyget_debug
#endif

#ifdef yyset_debug
#define miniyyset_debug_ALREADY_DEFINED
#else
#define yyset_debug miniyyset_debug
#endif

#ifdef yyget_extra
#define miniyyget_extra_ALREADY_DEFINED
#else
#define yyget_extra miniyyget_extra
#endif

#ifdef yyset_extra
#define miniyyset_extra_ALREADY_DEFINED
#else
#define yyset_extra miniyyset_extra
#endif

#ifdef yyget_in
#define miniyyget_in_ALREADY_DEFINED
#else
#define yyget_in miniyyget_in
#endif

#ifdef yyset_in
#define miniyyset_in_ALREADY_DEFINED
#else
#define yyset_in miniyyset_in
#endif

#ifdef yyget_out
#define miniyyget_out_ALREADY_DEFINED
#else
#define yyget_out miniyyget_out
#endif

#ifdef yyset_out
#define miniyyset_out_ALREADY_DEFINED
#else
#define yyset_out miniyyset_out
#endif

#ifdef yyget_leng
#define miniyyget_leng_ALREADY_DEFINED
#else
#define yyget_leng miniyyget_leng
#endif

#ifdef yyget_text
#define miniyyget_text_ALREADY_DEFINED
#else
#define yyget_text miniyyget_text
#endif

#ifdef yyget_lineno
#define miniyyget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno miniyyget_lineno
#endif

#ifdef yyset_lineno
#define miniyyset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno miniyyset_lineno
#endif

#ifdef yyget_column
#define miniyyget_column_ALREADY_DEFINED
#else
#define yyget_column miniyyget_column
#endif

#ifdef yyset_column
#define miniyyset_column_ALREADY_DEFINED
#else
#define yyset_column miniyyset_column
#endif

#ifdef yywrap
#define miniyywrap_ALREADY_DEFINED
#else
#define yywrap miniyywrap
#endif

#ifdef yyget_lval
#define miniyyget_lval_ALREADY_DEFINED
#else
#define yyget_lval miniyyget_lval
#endif

#ifdef yyset_lval
#define miniyyset_lval_ALREADY_DEFINED
#else
#define yyset_lval miniyyset_lval
#endif

#ifdef yyalloc
#define miniyyalloc_ALREADY_DEFINED
#else
#define yyalloc miniyyalloc
#endif

#ifdef yyrealloc
#define miniyyrealloc_ALREADY_DEFINED
#else
#define yyrealloc miniyyrealloc
#endif

#ifdef yyfree
#define miniyyfree_ALREADY_DEFINED
#else
#define yyfree miniyyfree
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define miniyywrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 247
#define YY_END_OF_BUFFER 248
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[1214] =
    {   0,
        0,    0,    0,    0,  248,  246,  242,  244,  243,   23,
      246,  245,  246,  246,   14,   15,   49,   47,   22,   48,
       32,   50,    7,    7,    7,   44,   24,   25,   20,   30,
       33,   42,   75,  245,  245,  245,  245,  245,  245,  245,
       16,   17,   51,  245,  245,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  227,   36,  228,  170,
        3,    4,    3,   18,    0,   13,    0,  245,    0,   34,
       26,    0,    0,    0,    0,    7,    7,   45,    1,    0,
        0,    0,    7,    7,    0,    0,    0,    0,    0,    0,

        0,   46,   43,   21,   19,   29,   28,   27,    0,    0,
       79,   81,   78,  245,  245,   12,   77,  111,  114,  112,
      113,   76,   80,  245,  245,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  223,  245,  245,  245,  245,  245,
      245,  224,  245,  245,  245,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  245,  245,  245,  245,
      245,  216,  245,  220,  245,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  241,  101,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  222,  245,  245,  245,

      245,  245,  245,  245,  245,  245,  245,   35,    2,    0,
        0,    0,    0,    0,   31,    0,    5,    0,    8,    0,
        7,    0,    0,   11,    0,    0,    0,    0,    7,   54,
       70,  245,  245,  245,  245,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  245,  245,  245,   59,
      245,  245,  245,  245,  245,  245,  245,  245,  245,  201,
      245,  245,  245,  226,   71,  245,  245,  245,   53,  245,
      245,  245,  245,  245,  245,  219,  245,  245,  245,  245,
      245,  200,  245,  245,  245,  245,  245,  245,  245,  245,
      245,  129,  245,  245,  245,  245,  245,  245,   55,  245,

      245,  133,  130,  132,  202,   41,  245,  245,  102,  245,
      245,  245,  245,  245,  245,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  245,  245,  245,  245,
      245,  245,  245,   58,  245,  245,  245,  245,  131,  245,
       60,  245,  245,  245,  245,  245,  245,   37,  245,  245,
      245,  245,  245,  245,  245,    0,    0,    0,    0,    0,
        0,    9,    0,    0,    0,    0,  245,  245,   62,  245,
      245,   61,   63,  245,  245,  245,  245,  245,  194,  245,
      245,   82,  245,  245,  245,  245,  245,   65,  245,  245,
      245,  245,   86,  245,  148,  245,  245,  245,  245,  218,

       72,  245,  245,  245,  245,  245,  245,  245,  245,  107,
      245,  245,  245,  245,  245,  245,  221,  245,  245,  245,
      245,  245,  245,  121,  245,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  240,  245,   56,  245,
      245,  245,  245,  245,  245,  245,  245,  180,  245,  245,
      245,   84,  245,   38,  144,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  245,  245,  245,   64,
      124,   52,  245,  245,  245,  245,  245,  128,   66,  245,
      217,   94,  245,  245,  116,  245,  245,  232,  245,  120,
      245,  245,  245,    0,    0,    0,    7,    0,    0,    0,

        0,    0,    0,    9,    0,    0,    7,  245,  245,   68,
      245,  245,   67,   69,  245,  245,  245,  225,  245,  245,
      245,  245,  245,  245,  166,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  141,  245,  245,  245,
       74,  245,  245,  117,  245,  139,  245,   83,  245,  245,
      245,  245,  245,  245,  245,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  245,  245,   57,   73,
      245,  119,  245,  245,  245,  245,  174,  245,  245,  245,
      245,  245,  175,  245,  236,  245,  245,  245,  245,  150,
      245,  245,  245,  245,  172,  245,  245,  245,  245,  245,

      245,  245,  245,  245,  245,  245,  245,  245,  245,  229,
      245,  190,  245,    7,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    6,  245,  245,  245,  245,  245,
      245,  245,  245,  165,  105,  245,  245,  245,  245,  245,
      245,  245,  245,  160,  245,  245,  245,  245,  245,  245,
       75,  103,  245,  245,  154,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  245,  245,  245,  245,
      153,  245,  245,  245,  245,  245,  245,  245,  135,  245,
      245,  245,  245,  245,  235,  245,   85,  245,  104,  245,
      245,  245,  245,  245,  245,  245,  245,  245,  245,  245,

      245,  245,  192,  245,   40,  123,  245,  245,  245,  245,
      245,  238,  245,  245,  245,  245,  156,   93,  245,  245,
      245,  245,  245,    0,    7,    0,    0,    7,    0,    6,
        0,    0,    0,  245,  245,  245,  245,  245,  245,  245,
      245,  239,  245,  245,  245,  245,  245,  138,  118,  245,
      245,  245,  245,  245,   87,  245,  245,  245,  179,  245,
      245,  245,  245,  245,  245,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  195,  237,  245,  245,  143,
      245,  146,  245,  245,  245,  245,  245,  110,  245,  245,
      245,  245,  245,  245,  245,  245,  245,  245,  245,  245,

      134,  245,  145,  245,  245,  245,  245,  245,  167,  245,
      196,  245,  245,  245,  245,  245,  245,  245,  245,    0,
        0,    0,    0,    0,    0,    0,    6,  136,  245,  245,
      245,  159,  245,  245,  245,  245,  245,  245,  245,  233,
      245,  245,  245,  245,  245,  245,  245,  245,  173,  126,
      245,  245,  140,  245,  245,  245,  234,  245,  245,  245,
      245,  245,  245,  245,  245,  204,  245,  245,  245,  125,
      245,  245,  245,  245,  245,  245,  245,  245,  245,  245,
      245,  245,  178,  245,  245,  142,  137,  245,  245,  245,
      245,  245,  155,  245,  245,  245,  245,  245,  245,  245,

      245,  245,    0,    6,    0,  245,  245,  191,  245,  245,
      245,   90,  245,  245,  245,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  197,  245,  152,  245,  245,
      245,  245,  245,  245,  245,  245,  245,  245,  245,  245,
      245,  245,  161,  245,  245,  127,  245,  245,  245,  245,
      181,  245,   39,  245,  245,  245,  245,  245,  213,  245,
      245,  245,  245,  245,  245,  245,  245,   88,  206,  245,
       10,  245,  245,  245,  245,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  245,  245,  245,  245,

      245,  245,  245,  245,  245,  245,  193,  108,  245,  245,
      245,  182,  245,  245,  245,  245,  245,  245,  245,  245,
      163,  245,  157,  245,  245,  245,  245,    0,  245,  245,
      245,  245,  185,  245,  245,  245,  162,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  245,  198,  245,  245,
      245,  214,  245,  106,  245,  245,  245,  245,  209,  212,
      245,  245,  203,  245,  183,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  245,  245,    0,  245,
      245,   91,  186,  245,  210,  245,  245,  245,  199,  245,
      245,  245,  231,  189,  230,  245,  188,  245,  245,  245,

      245,  245,  245,  245,   96,  245,  245,  245,   99,  245,
      245,  245,  245,  155,  245,  245,  245,  245,    0,  245,
      245,  158,  245,  245,  245,  205,  149,  245,  245,  245,
      245,  245,  245,  207,  245,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  245,    0,  245,  245,  245,
       97,  215,  245,  245,  115,  245,  245,  245,  109,  184,
      169,  245,  122,  245,  245,  245,  245,  245,  245,    0,
      171,  245,  245,   95,  245,  245,  245,  147,  245,  245,
      245,  176,  245,  245,  245,    0,  151,  245,  245,  245,
      245,  245,   98,  245,   92,  245,  211,    0,  245,  245,

      100,  208,  168,  245,  177,   10,  164,  245,   89,  245,
      245,  187,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    1,    8,    9,   10,   11,   12,
       13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
       23,   23,   23,   23,   23,   24,   24,   25,   26,   27,
       28,   29,   30,   31,   32,   33,   34,   35,   36,   34,
       37,   38,   39,   40,   40,   40,   40,   41,   40,   42,
       43,   44,   45,   46,   47,   40,   40,   48,   40,   49,
       50,   51,   52,   53,   54,    1,   55,   56,   57,   58,

       59,   60,   61,   62,   63,   64,   65,   66,   67,   68,
       69,   70,   71,   72,   73,   74,   75,   76,   77,   78,
       79,   80,   81,   82,   83,   84,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    8,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    8,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[85] =
    {   0,
        1,    1,    1,    1,    1,    1,    2,    3,    1,    1,
        2,    1,    1,    1,    1,    1,    1,    4,    1,    5,
        5,    5,    5,    6,    1,    1,    1,    1,    1,    2,
        1,    6,    6,    6,    6,    6,    3,    3,    3,    3,
        3,    7,    3,    3,    3,    3,    3,    3,    3,    1,
        2,    1,    1,    3,    5,    5,    6,    6,    6,    5,
        3,    3,    3,    3,    3,    3,    3,    8,    3,    7,
        3,    8,    3,    8,    3,    8,    3,    8,    3,    3,
        1,    1,    1,    1
    } ;

static const flex_int16_t yy_base[1238] =
    {   0,
        0,    0,   82,   83, 1684, 1685, 1685, 1685, 1685, 1655,
       80,    0,   68, 1672, 1685, 1685, 1654, 1685, 1685,   88,
       80,   80,  127,   47,  134,   89, 1685, 1685, 1652,  105,
     1685,   74,   85, 1637,   86, 1615, 1642,   81, 1639, 1640,
     1685, 1685, 1685, 1596,  105,   74,  129,  113,   68,  134,
       67,  153,  134,  105,  158,  141,  109,  160, 1598,  165,
      174,  184, 1604,  183,  188, 1612, 1685, 1588, 1685, 1685,
     1685, 1685, 1650, 1685,  120, 1685,  241,    0,  245, 1685,
     1685,  253,  258,  265, 1650,  279,  285, 1685, 1685, 1664,
      236,  290,  139,  319,  305,  336, 1648, 1643, 1646,  344,

      350, 1685, 1685, 1685, 1685, 1685, 1685, 1685, 1595, 1607,
        0,    0,    0, 1620, 1619,    0,    0,    0,    0,    0,
        0,    0,    0, 1605, 1585,  171, 1589,  168, 1601, 1581,
     1581,  105, 1585, 1583,    0, 1583, 1587, 1590,  317,  236,
      322, 1573, 1592, 1573, 1587,  258, 1589,  185, 1577,  268,
     1573, 1569,  231, 1571,  226, 1581, 1564, 1578, 1570,  276,
      319,    0, 1565,  287,   79, 1566,  289, 1572,  318,  325,
     1574, 1563, 1560, 1562, 1564, 1567,    0, 1554, 1553, 1555,
      334,  341,  325,  249,  346, 1548, 1567, 1552,  338, 1548,
     1547, 1546,  346,  355, 1558, 1549,    0,  346, 1542, 1542,

     1541, 1549, 1548, 1536, 1537, 1545, 1535, 1685, 1685,  408,
        0,  415,  420,  425, 1685, 1603, 1685,  430,  440,  445,
      450,    0,  414, 1685,  415,  456, 1545, 1563,    0,    0,
     1534, 1527, 1528, 1531, 1536, 1530, 1529, 1527, 1533, 1531,
     1524,  277, 1526, 1522, 1524,  369, 1529, 1518, 1514, 1524,
     1522, 1529, 1511, 1513, 1514, 1511, 1519, 1504, 1507,    0,
     1520, 1517, 1515,    0, 1516, 1503, 1505, 1513,  426, 1510,
     1495, 1508, 1508, 1506,  427,    0, 1501, 1500, 1495, 1495,
     1503,    0,  427, 1486, 1498, 1499, 1501, 1486, 1491, 1485,
     1486,  418, 1492, 1481, 1473, 1487, 1475, 1472,  466, 1471,

     1487,    0, 1473,    0,    0,    0,  399, 1483,    0, 1468,
     1466, 1465, 1470, 1463, 1477, 1478, 1466, 1476, 1474, 1457,
     1469, 1466, 1470, 1472, 1467, 1470, 1450, 1448, 1463, 1453,
     1448, 1442, 1448,  428, 1443, 1442, 1452,  421,  280, 1448,
     1451, 1446, 1443,  136, 1440, 1450, 1433,    0, 1451, 1448,
     1439, 1442, 1430, 1428, 1432,  490,  535,  485,  498,  357,
      457,  508,  496,  513, 1469, 1468, 1432, 1425, 1434, 1421,
     1431, 1431, 1430,  466, 1432, 1422, 1414, 1416,    0, 1428,
     1418,    0, 1406, 1419, 1423, 1413, 1407,    0, 1413, 1404,
     1419, 1410,    0, 1408,    0, 1396, 1408, 1407, 1409,    0,

        0, 1399, 1395, 1394, 1400, 1446, 1398, 1393, 1405,    0,
     1383, 1404, 1387, 1388, 1391, 1390,    0, 1387, 1382, 1400,
     1379, 1380, 1382,    0, 1393, 1378, 1375, 1389, 1388, 1377,
     1366,  479, 1369, 1388, 1368, 1386,    0,  482,    0, 1377,
     1377, 1369, 1378, 1364, 1378, 1375, 1358,    0, 1358, 1358,
     1358, 1366, 1354, 1368,    0, 1367, 1356,  483, 1350, 1343,
     1355, 1366, 1348, 1347, 1360, 1360, 1349, 1349, 1348,    0,
        0,    0, 1345, 1343, 1337, 1341, 1337,    0,    0, 1339,
        0,    0, 1339, 1340,    0, 1335, 1335,    0, 1344,    0,
     1328, 1342, 1342,  494,  537,  552,  560,  508,  522, 1331,

     1343,  577,  582,  587,  545,  600, 1685, 1322, 1341,    0,
     1340, 1324,    0,    0, 1330, 1329,  484,    0, 1317, 1311,
     1334, 1325, 1314, 1323,    0, 1312, 1329, 1328, 1316, 1322,
     1317, 1320,  553, 1323, 1318, 1319,    0, 1320, 1300, 1315,
        0, 1313, 1303,    0, 1311,    0, 1306,    0, 1310, 1304,
     1311, 1302, 1307, 1293, 1304, 1289, 1301, 1302, 1303, 1285,
     1289, 1283,  553, 1284, 1285, 1286, 1289, 1278,    0,    0,
     1276,    0, 1285, 1275, 1291, 1271,    0, 1272, 1270, 1285,
     1268, 1267,  571, 1281,    0, 1270, 1274, 1269, 1272,    0,
     1275, 1261, 1264, 1257,  522, 1268, 1270, 1265, 1268, 1265,

     1259, 1261, 1251, 1263, 1249, 1259, 1260, 1248, 1244,    0,
     1259,    0, 1256,  630,  609,  617, 1246, 1258, 1271, 1270,
     1250, 1241,  635,  600,  612, 1234, 1233, 1232, 1239, 1244,
     1236, 1247, 1242,    0,    0, 1232, 1242, 1236, 1229, 1237,
     1227, 1228, 1219,    0, 1224, 1219, 1227, 1221, 1225, 1208,
      588,    0, 1212, 1226,    0, 1216, 1228, 1210, 1213, 1200,
     1212, 1206, 1208, 1211, 1205, 1215, 1214, 1215, 1202, 1204,
        0, 1210, 1201, 1195, 1211, 1196, 1206, 1188,    0, 1183,
     1188, 1192, 1187, 1184, 1189, 1200,    0, 1183,    0, 1191,
     1190, 1183, 1173, 1184, 1190, 1185, 1180, 1171, 1190, 1178,

     1177, 1166,    0, 1167,    0,    0, 1171, 1171, 1177, 1164,
     1176,    0, 1156, 1160, 1166, 1159,  600,    0, 1094, 1079,
     1086, 1093, 1074,  641,  653, 1063, 1081, 1685, 1047,  631,
      651,  673,  677, 1061, 1059, 1058, 1047, 1055, 1044, 1047,
     1055,    0, 1055, 1050, 1048, 1037, 1032,    0,    0, 1050,
     1032, 1035,  490, 1035,    0, 1032, 1022, 1040,    0, 1024,
     1029, 1025, 1032, 1033, 1035, 1030, 1020, 1013, 1014, 1024,
     1027, 1019, 1021, 1007, 1010,    0,    0, 1011, 1010,    0,
      159,  173,  180,  180,  201,  247,  324,    0,  345,  348,
      430,  440,  476,  520,  550,  575,  613,  608,  615,  623,

        0,  624,    0,  632,  624,  631,  614,  609,    0,  620,
        0,  623,  633,  644,  636,  647,  633,  635,  641,  680,
      681,  634,  709,  703,  697,  713,  720,    0,  653,  657,
      648,    0,  662,  654,  655,  665,  662,  678,  678,    0,
      674,  680,  692,  683,  693,  683,  679,  681,    0,    0,
      699,  683,    0,  686,  681,  692,    0,  689,  703,  691,
      701,  698,  706,  711,  697,    0,  717,  717,  705,    0,
      708,  707,  705,  711,  709,  712,  726,  726,  728,  729,
      730,  725,    0,  728,  733,    0,    0,  729,  718,  714,
      726,  738,  721,  721,  729,  725,  741,  724,  728,  723,

      744,  737,  785,  790,  797,  748,  742,    0,  755,  764,
      746,    0,  761,  753,  757,  755,  753,  746,  758,  767,
      763,  774,  772,  777,  768,    0,  764,    0,  761,  781,
      764,  779,  768,  787,  783,  787,  788,  772,  781,  780,
      780,  776,    0,  792,  778,    0,  781,  788,  787,  782,
        0,  791,    0,  789,  791,  801,  803,  808,    0,  803,
      810,  807,  809,  802,  795,  815,  799,    0,    0,  810,
      856,  815,  808,  817,  804,  820,  811,  809,  803,  811,
      817,  826,  814,  815,  825,  823,  822,  817,  823,  824,
      821,  833,  839,  824,  840,  837,  835,  832,  828,  835,

      836,  847,  848,  835,  851,  837,    0,  851,  833,  854,
      841,    0,  856,  846,  859,  855,  862,  848,  862,  862,
        0,  850,    0,  852,  859,  860,  860,  911,  862,  874,
      853,  874,    0,  862,  868,  868,    0,  868,  866,  872,
      885,  881,  883,  885,  889,  871,  889,    0,  888,  889,
      890,    0,  881,    0,  879,  880,  886,  889,    0,    0,
      882,  898,    0,  895,    0,  896,  888,  902,  905,  889,
      896,  897,  907,  894,  895,  910,  911,  916,  954,  904,
      900,    0,    0,  908,    0,  907,  919,  909,    0,  913,
      901,  923,    0,    0,    0,  910,    0,  926,  917,  927,

      914,  915,  910,  935,    0,  925,  923,  924,    0,  931,
      929,  934,  923,    0,  944,  937,  928,  928,  985,  932,
      942,    0,  939,  948,  935,    0,    0,  951,  951,  944,
      955,  950,  940,    0,  947,  957,  949,  940,  960,  941,
      953,  955,  962,  956,  953,  959, 1011,  963,  962,  969,
        0,    0,  960,  975,    0,  966,  981,  963,    0,    0,
        0,  970,    0,  978,  984,  982,  974,  988,  972, 1027,
        0,  978,  992,    0,  975,  981,  982,    0,  977,  979,
      995,    0,  983,  996,  985, 1041,    0,  994,  988,  989,
      989,  991,    0,  993,    0, 1007,    0, 1049,  995, 1015,

        0,    0,    0,  998,    0, 1054,    0, 1012,    0, 1015,
     1002,    0, 1685, 1124, 1132, 1138, 1145, 1153, 1158, 1161,
     1163, 1165, 1168, 1172, 1176, 1180, 1184, 1188, 1192, 1196,
     1200, 1204, 1208, 1212, 1216, 1220, 1224
    } ;

static const flex_int16_t yy_def[1238] =
    {   0,
     1213,    1, 1214, 1214, 1213, 1213, 1213, 1213, 1213, 1213,
     1215, 1216, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213,
     1213, 1213, 1213,   23, 1213, 1213, 1213, 1213, 1213, 1213,
     1213, 1213, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1213, 1213, 1213, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1213, 1213, 1213, 1213,
     1213, 1213, 1213, 1213, 1215, 1213, 1217, 1216, 1213, 1213,
     1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1218,
     1213, 1213,   23, 1213, 1213, 1213, 1219, 1213, 1220, 1213,

     1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,

     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1213, 1213, 1215,
     1221, 1213, 1213, 1213, 1213, 1218, 1213, 1213, 1213, 1213,
     1213, 1222, 1219, 1213, 1223, 1213, 1213, 1213, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,

     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1215, 1215, 1213, 1213, 1222,
     1222, 1213, 1224, 1213, 1213, 1213, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,

     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1215, 1215, 1213, 1213, 1213, 1213, 1213,

     1213, 1213, 1213, 1213, 1225, 1213, 1213, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,

     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1213, 1213, 1213, 1213, 1213, 1213, 1213,
     1213, 1213, 1213, 1226, 1213, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,

     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1213, 1213, 1213, 1213, 1213, 1213, 1213,
     1227, 1213, 1213, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,

     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1213,
     1213, 1213, 1213, 1213, 1228, 1213, 1213, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,

     1216, 1216, 1213, 1213, 1229, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1230, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,

     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1231, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1232, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,

     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1233, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1234, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1235,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1236, 1216, 1216, 1216, 1216,
     1216, 1216, 1216, 1216, 1216, 1216, 1216, 1237, 1216, 1216,

     1216, 1216, 1216, 1216, 1216, 1219, 1216, 1216, 1216, 1216,
     1216, 1216,    0, 1213, 1213, 1213, 1213, 1213, 1213, 1213,
     1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213,
     1213, 1213, 1213, 1213, 1213, 1213, 1213
    } ;

static const flex_int16_t yy_nxt[1770] =
    {   0,
        6,    7,    8,    9,    7,   10,   11,   12,   13,   14,
        6,   15,   16,   17,   18,   19,   20,   21,   22,   23,
       24,   25,   25,   25,   26,   27,   28,   29,   30,   31,
       32,   12,   12,   12,   33,   12,   12,   34,   12,   12,
       35,   36,   37,   38,   39,   40,   12,   12,   12,   41,
        6,   42,   43,   44,   45,   46,   47,   48,   49,   50,
       51,   52,   53,   12,   12,   54,   55,   56,   57,   58,
       59,   60,   61,   62,   63,   64,   65,   12,   12,   66,
       67,   68,   69,   70,   72,   72,   76,   79,   79,   79,
       79,   79,   82,   89, 1213,   73,   73,   85,   90,   86,

       86,   87,   87,   87,   88,   83,  102,   84,   84,   84,
       84,   84,  109,  103,  110,  118,  104,  114,  106,  111,
      112,  119,  107,  156, 1213,  157,   76,  120,  131,  121,
       77,   91,  132,  144,  294,  145,  133,  295,   91,  146,
      115,  158,  134,  147,   92,  148,   93,   93,   94,   94,
       94,  101,  135,   94,   94,   94,   94,   94,  108,   95,
      125,  126,   96,  166,  175,  240,   95,  167,  176,   96,
       77,  140,  127,  168,   97,  141,  177,  128,  129,  130,
       98,  142,   95,  136,  241,   96, 1213,  137,  149,   95,
      138,  143,   96,  162,  482,  172,  150,  139,  483,  151,

      163,  164,  152,  153,   99,  154,  165,  159,  155,  173,
      100,  160,  169,  868,  178,  174, 1213,  100,  179,  184,
      170,  161,  116,  185,  235,  180,  171,  232,  181,  869,
      236,  182,  187,  186,  870,  188,  189,  200,  194,  233,
       91,  201,  190,  268,  191,  195,  196,  192,  193,  203,
      204,  202,  197,  871,  269,  198,  205,   82,  270,  206,
      210,  210,  210,  210,  212,  212,  212,  212,  212,  872,
       83,   96,   84,   84,   84,   84,   84,  213,  213,  213,
      213,  213,   83,   91,   84,   84,   84,   84,   84,   91,
      277,  280,  251,  281,   96,  252,  253,  278,   86,   86,

       87,   87,   87,  254,   87,   87,   87,   87,   87,   86,
       86,   87,   87,   87,   96,  873,  321,  265,  211,  218,
       96,  218,  322,   91,  219,  219,  219,  219,  219,  266,
      286,  378,   98,  272,  379,  273,  101,   96,   94,   94,
       94,   94,   94,   96,  297,  274,  292,  476,  214,  477,
      220,   95,  220,  287,   96,  221,  221,  221,  221,  221,
      293,  298,  100,  226,  226,  226,  226,  226,  100,   87,
       87,   87,   87,   87,   95,  247,  255,   96,  874,  319,
      256,  257,  303,  248,  249,  300,  288,  320,  289,  250,
      290,  301,  304,  258,  259,  302,  313,  260,  362,  316,

      323,  338,  100,  317,  333,  334,  314,  875,  345,  318,
      315,  324,  325,  326,   76,  339,  876,  340,  327,  328,
      346,  329,  341,  358,  383,  384,  362,  356,  356,  356,
      356,  361,  361,  342,  212,  212,  212,  212,  212,  213,
      213,  213,  213,  213,  359,  359,  359,  359,  359,  219,
      219,  219,  219,  219,  443,  362,  362,  444,   77,  219,
      219,  219,  219,  219,  221,  221,  221,  221,  221,  221,
      221,  221,  221,  221,  364,  226,  226,  226,  226,  226,
      405,  413,  420,  362,  362,  430,  438,  439,  469,  470,
      474,  431,  406,  475,  407,  414,   76,  877,  362,  421,

       76,  569,  496,  214,  497,  497,  497,  497,  497,  494,
      494,  494,  494,  361,  878,  498,  502,  359,  359,  359,
      359,  359,  503,  515,  503,  499,  362,  504,  504,  504,
      504,  504,  506,  506,  506,  506,  506,  362,  516,  563,
       77,   76,  587,   76,   77,  879,  617,  500,  618,  844,
      564,  570,  501,  619,  495,  495,  495,  495,  495,  632,
      588,  633,  361,  845,  615,  362,  495,  495,  495,  495,
      495,  614,  614,  614,  614,  614,  620,  496,  707,  497,
      497,  497,  497,  497,  708,   77,  362,   77,  880,  495,
      495,  495,  495,  495,  495,  616,  623,  623,  623,  623,

      623,  504,  504,  504,  504,  504,  504,  504,  504,  504,
      504,  674,  647,  615,  362,  648,  732,  361,  616,  506,
      506,  506,  506,  506,  675,  649,  691,  881,  692,  693,
      694,  724,  695,  724,  615,  823,  725,  725,  725,  725,
      725,  362,  882,  696,  616,  756,  757,  733,  697,  614,
      614,  614,  614,  614,  623,  623,  623,  623,  623,  813,
      725,  725,  725,  725,  725,  616,  824,  616,  361,  362,
      733,  814,  725,  725,  725,  725,  725,  732,  883,  884,
      885,  886,  887,  625,  890,  891,  892,  893,  616,  824,
      888,  826,  362,  826,  894,  895,  827,  827,  827,  827,

      827,  896,  897,  889,  898,  899,  900,  901,  733,  902,
      728,  728,  728,  823,  361,  906,  907,  903,  730,  903,
      362,  908,  904,  904,  904,  904,  904,  909,  910,  911,
      912,  733,  827,  827,  827,  827,  827,  913,  362,  827,
      827,  827,  827,  827,  824,  914,  915,  916,  917,  918,
      919,  920,  921,  922,  923,  926,  924,  927,  928,  929,
      930,  931,  932,  933,  934,  935,  362,  824,  925,  936,
      937,  938,  939,  940,  941,  942,  943,  944,  945,  946,
      947,  948,  949,  950,  951,  952,  953,  954,  956,  957,
      958,  959,  960,  961,  962,  963,  964,  965,  966,  955,

      967,  968,  969,  970,  904,  904,  904,  904,  904,  904,
      904,  904,  904,  904,  361,  972,  973,  974,  975,  976,
      977,  978,  979,  980,  981,  982,  983,  984,  985,  986,
      987,  988,  991,  989,  992,  993,  994,  995,  362,  990,
      996,  997,  998,  999, 1000, 1002, 1003, 1004, 1005, 1006,
     1007, 1008, 1009, 1010, 1011, 1012, 1013, 1001, 1014, 1015,
     1016, 1017, 1018, 1019, 1020, 1021,  362, 1022, 1023, 1024,
     1025, 1026, 1027,  361, 1029, 1030, 1031, 1032, 1033, 1034,
     1035, 1036, 1037, 1038, 1039, 1040, 1041, 1042, 1043, 1044,
     1045, 1046, 1047, 1048, 1049, 1050, 1051,  362, 1052, 1053,

     1054, 1055, 1056, 1057, 1058, 1059, 1060, 1061, 1062, 1063,
     1064, 1065,  951, 1066, 1012, 1067, 1068, 1069, 1070, 1071,
     1072, 1073, 1074, 1075, 1076,  362, 1077, 1078,  361, 1080,
     1081, 1082, 1083, 1084, 1085, 1086, 1087, 1088, 1089, 1090,
     1091,  111, 1092, 1093, 1094, 1095, 1096, 1097, 1098, 1099,
     1100, 1101,  362, 1102, 1103, 1104, 1105, 1106, 1107, 1108,
     1109, 1110, 1111, 1112, 1113, 1114, 1115, 1116,  123, 1117,
     1118,  361, 1120, 1121, 1122, 1123, 1124, 1125, 1126, 1127,
      362, 1128, 1129, 1130,  113, 1131, 1132, 1133, 1134, 1135,
     1136, 1137, 1138, 1139, 1140,  362, 1141, 1142, 1143, 1144,

     1145, 1146,  361, 1148, 1149, 1150, 1151, 1152,  112, 1153,
     1154, 1155, 1156, 1157, 1158, 1159, 1160, 1161, 1162, 1163,
     1164, 1165, 1166,  362, 1167, 1168,  362, 1169,  361, 1171,
     1172, 1173, 1174, 1175, 1176, 1177, 1178, 1179, 1180, 1181,
     1182, 1183, 1184, 1185,  361, 1187, 1188, 1189, 1190, 1191,
     1192, 1193,  362, 1194,  362, 1195, 1196, 1197,  361, 1199,
     1200, 1201, 1202, 1203, 1204, 1205,  361, 1207,  362, 1208,
     1209,  361, 1210, 1211, 1212,  867,  866,  865,  864,  863,
      362,  862,  362,  861,  860,  859,  858,  857,  856,  855,
      362,  854,  853,  852,  851,  362,  362,  850,  849,  848,

      847,  846,  843,  842,  841,  840,  839,  838,  837,  836,
      362,  835,  834,  833,  832,  831,  830,  829,  362,  828,
      822,  821,  820,  362,   71,   71,   71,   71,   71,   71,
       71,   71,   75,   75,   75,   75,   75,   75,   75,   75,
       78,  819,   78,   78,   78,   78,   75,  818,  817,   75,
      816,  815,   75,  216,  216,  216,  216,  216,  216,  216,
      216,  223,  223,  223,  225,  225,  225,  357,  357,  360,
      360,  363,  363,  363,  363,  505,  505,  505,  505,  624,
      624,  624,  624,  731,  731,  731,  731,  825,  825,  825,
      825,  905,  905,  905,  905,  971,  971,  971,  971, 1028,

     1028, 1028, 1028, 1079, 1079, 1079, 1079, 1119, 1119, 1119,
     1119, 1147, 1147, 1147, 1147, 1170, 1170, 1170, 1170, 1186,
     1186, 1186, 1186, 1198, 1198, 1198, 1198, 1206, 1206, 1206,
     1206,  812,  811,  810,  809,  808,  807,  806,  805,  804,
      803,  802,  801,  800,  799,  798,  797,  796,  795,  794,
      793,  792,  791,  790,  789,  788,  787,  786,  785,  784,
      783,  782,  781,  780,  779,  778,  777,  776,  775,  774,
      773,  772,  771,  770,  769,  768,  767,  766,  765,  764,
      763,  762,  761,  760,  759,  758,  755,  754,  753,  752,
      751,  750,  749,  748,  747,  746,  745,  744,  743,  742,

      741,  740,  739,  738,  737,  736,  735,  734,  728,  729,
      728,  728,  727,  726,  723,  722,  721,  720,  719,  718,
      717,  716,  715,  714,  713,  712,  122,  711,  710,  709,
      706,  705,  704,  703,  702,  701,  700,  699,  698,  690,
      689,  688,  687,  686,  685,  684,  683,  682,  681,  680,
      679,  678,  677,  676,  673,  672,  671,  670,  669,  668,
      667,  666,  665,  664,  663,  662,  661,  660,  659,  658,
      657,  656,  655,  654,  653,  652,  651,  650,  646,  645,
      644,  643,  642,  641,  640,  639,  638,  637,  636,  635,
      634,  631,  630,  629,  628,  627,  626,  622,  621,  613,

      612,  611,  610,  609,  608,  607,  606,  605,  604,  603,
      602,  601,  600,  599,  598,  597,  596,  595,  594,  593,
      592,  591,  590,  589,  586,  585,  584,  583,  582,  581,
      580,  579,  578,  577,  576,  575,  574,  573,  572,  571,
      568,  567,  566,  565,  229,  562,  561,  560,  559,  558,
      557,  556,  555,  554,  553,  552,  551,  550,  549,  548,
      547,  546,  545,  544,  543,  542,  541,  540,  539,  538,
      537,  536,  535,  534,  533,  532,  531,  530,  529,  528,
      527,  526,  525,  524,  523,  522,  521,  520,  519,  518,
      517,  514,  513,  512,  511,  510,  509,  508,  507,  507,

      493,  492,  491,  490,  489,  488,  487,  486,  485,  484,
      481,  480,  479,  478,  473,  472,  471,  468,  467,  466,
      465,  464,  463,  462,  461,  460,  459,  458,  457,  456,
      455,  117,  454,  453,  452,  451,  450,  449,  448,  447,
      446,  445,  442,  441,  440,  437,  436,  435,  434,  433,
      432,  429,  428,  427,  426,  425,  424,  423,  422,  419,
      418,  417,  416,  415,  412,  411,  410,  409,  408,  404,
      403,  402,  401,  400,  399,  398,  397,  396,  395,  394,
      393,  392,  391,  390,  389,  388,  387,  386,  385,  382,
      381,  380,  377,  376,  375,  374,  373,  372,  371,  370,

      369,  368,  367,  366,  365,  217,  355,  354,  353,  352,
      351,  350,  349,  348,  347,  344,  343,  337,  336,  335,
      332,  331,  330,  312,  311,  310,  309,  308,  307,  306,
      229,  305,  299,  296,  291,  285,  284,  283,  282,  279,
      276,  275,  271,  267,  264,  263,  262,  261,  246,  245,
      244,  243,  242,  239,  238,  237,  234,  231,  230,  229,
      229,  228,  227,  222,  224,  222,  217,  215,  209,  208,
      207,  199,  183,  124,  123,  122,  117,  116,  113,  105,
       81,   80,   74, 1213,    5, 1213, 1213, 1213, 1213, 1213,
     1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213,

     1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213,
     1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213,
     1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213,
     1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213,
     1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213,
     1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213,
     1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213
    } ;

static const flex_int16_t yy_chk[1770] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    3,    4,   11,   13,   13,   13,
       13,   13,   20,   22,   24,    3,    4,   21,   22,   21,

       21,   21,   21,   21,   21,   20,   26,   20,   20,   20,
       20,   20,   32,   26,   32,   38,   26,   35,   30,   33,
       33,   38,   30,   51,   24,   51,   75,   38,   46,   38,
       11,   23,   46,   49,  165,   49,   46,  165,   25,   49,
       35,   51,   46,   49,   23,   49,   23,   23,   23,   23,
       23,   25,   46,   25,   25,   25,   25,   25,   30,   23,
       45,   45,   23,   54,   57,  132,   25,   54,   57,   25,
       75,   48,   45,   54,   23,   48,   57,   45,   45,   45,
       23,   48,   23,   47,  132,   23,   93,   47,   50,   25,
       47,   48,   25,   53,  344,   56,   50,   47,  344,   50,

       53,   53,   50,   50,   23,   50,   53,   52,   50,   56,
       23,   52,   55,  781,   58,   56,   93,   25,   58,   60,
       55,   52,   58,   60,  128,   58,   55,  126,   58,  782,
      128,   58,   61,   60,  783,   61,   61,   64,   62,  126,
       91,   64,   61,  148,   61,   62,   62,   61,   61,   65,
       65,   64,   62,  784,  148,   62,   65,   82,  148,   65,
       77,   77,   77,   77,   79,   79,   79,   79,   79,  785,
       82,   91,   82,   82,   82,   82,   82,   83,   83,   83,
       83,   83,   84,   86,   84,   84,   84,   84,   84,   87,
      153,  155,  140,  155,   91,  140,  140,  153,   86,   86,

       86,   86,   86,  140,   87,   87,   87,   87,   87,   92,
       92,   92,   92,   92,   86,  786,  184,  146,   77,   95,
       87,   95,  184,   94,   95,   95,   95,   95,   95,  146,
      160,  242,   86,  150,  242,  150,   94,   86,   94,   94,
       94,   94,   94,   87,  167,  150,  164,  339,   84,  339,
       96,   94,   96,  160,   94,   96,   96,   96,   96,   96,
      164,  167,   86,  100,  100,  100,  100,  100,   87,  101,
      101,  101,  101,  101,   94,  139,  141,   94,  787,  183,
      141,  141,  170,  139,  139,  169,  161,  183,  161,  139,
      161,  169,  170,  141,  141,  169,  181,  141,  360,  182,

      185,  193,   94,  182,  189,  189,  181,  789,  198,  182,
      181,  185,  185,  185,  210,  193,  790,  194,  185,  185,
      198,  185,  194,  212,  246,  246,  360,  210,  210,  210,
      210,  223,  225,  194,  212,  212,  212,  212,  212,  213,
      213,  213,  213,  213,  214,  214,  214,  214,  214,  218,
      218,  218,  218,  218,  307,  223,  225,  307,  210,  219,
      219,  219,  219,  219,  220,  220,  220,  220,  220,  221,
      221,  221,  221,  221,  226,  226,  226,  226,  226,  226,
      269,  275,  283,  223,  225,  292,  299,  299,  334,  334,
      338,  292,  269,  338,  269,  275,  356,  791,  361,  283,

      494,  438,  358,  213,  358,  358,  358,  358,  358,  356,
      356,  356,  356,  363,  792,  358,  359,  359,  359,  359,
      359,  359,  362,  374,  362,  358,  361,  362,  362,  362,
      362,  362,  364,  364,  364,  364,  364,  363,  374,  432,
      356,  357,  458,  495,  494,  793,  498,  358,  498,  753,
      432,  438,  358,  499,  357,  357,  357,  357,  357,  517,
      458,  517,  505,  753,  497,  363,  357,  357,  357,  357,
      357,  496,  496,  496,  496,  496,  499,  497,  595,  497,
      497,  497,  497,  497,  595,  357,  505,  495,  794,  357,
      357,  357,  357,  357,  357,  497,  502,  502,  502,  502,

      502,  503,  503,  503,  503,  503,  504,  504,  504,  504,
      504,  563,  533,  615,  505,  533,  625,  624,  497,  506,
      506,  506,  506,  506,  563,  533,  583,  795,  583,  583,
      583,  616,  583,  616,  614,  730,  616,  616,  616,  616,
      616,  624,  796,  583,  615,  651,  651,  625,  583,  614,
      614,  614,  614,  614,  623,  623,  623,  623,  623,  717,
      724,  724,  724,  724,  724,  614,  730,  615,  731,  624,
      625,  717,  725,  725,  725,  725,  725,  732,  797,  798,
      799,  800,  802,  506,  805,  806,  807,  808,  614,  730,
      804,  733,  731,  733,  810,  812,  733,  733,  733,  733,

      733,  813,  814,  804,  815,  816,  817,  818,  732,  819,
      820,  821,  822,  823,  825,  829,  830,  824,  623,  824,
      731,  831,  824,  824,  824,  824,  824,  833,  834,  835,
      836,  732,  826,  826,  826,  826,  826,  837,  825,  827,
      827,  827,  827,  827,  823,  838,  839,  841,  842,  843,
      844,  845,  846,  847,  848,  852,  851,  854,  855,  856,
      858,  859,  860,  861,  862,  863,  825,  823,  851,  864,
      865,  867,  868,  869,  871,  872,  873,  874,  875,  876,
      877,  878,  879,  880,  881,  882,  884,  885,  888,  889,
      890,  891,  892,  893,  894,  895,  896,  897,  898,  885,

      899,  900,  901,  902,  903,  903,  903,  903,  903,  904,
      904,  904,  904,  904,  905,  906,  907,  909,  910,  911,
      913,  914,  915,  916,  917,  918,  919,  920,  921,  922,
      923,  924,  927,  925,  929,  930,  931,  932,  905,  925,
      933,  934,  935,  936,  937,  938,  939,  940,  941,  942,
      944,  945,  947,  948,  949,  950,  952,  937,  954,  955,
      956,  957,  958,  960,  961,  962,  905,  963,  964,  965,
      966,  967,  970,  971,  972,  973,  974,  975,  976,  977,
      978,  979,  980,  981,  982,  983,  984,  985,  986,  987,
      988,  989,  990,  991,  992,  993,  994,  971,  995,  996,

      997,  998,  999, 1000, 1001, 1002, 1003, 1004, 1005, 1006,
     1008, 1009, 1010, 1011, 1013, 1014, 1015, 1016, 1017, 1018,
     1019, 1020, 1022, 1024, 1025,  971, 1026, 1027, 1028, 1029,
     1030, 1031, 1032, 1034, 1035, 1036, 1038, 1039, 1040, 1041,
     1042, 1043, 1044, 1045, 1046, 1047, 1049, 1050, 1051, 1053,
     1055, 1056, 1028, 1057, 1058, 1061, 1062, 1064, 1066, 1067,
     1068, 1069, 1070, 1071, 1072, 1073, 1074, 1075, 1076, 1077,
     1078, 1079, 1080, 1081, 1084, 1086, 1087, 1088, 1090, 1091,
     1028, 1092, 1096, 1098, 1099, 1100, 1101, 1102, 1103, 1104,
     1106, 1107, 1108, 1110, 1111, 1079, 1112, 1113, 1115, 1116,

     1117, 1118, 1119, 1120, 1121, 1123, 1124, 1125, 1128, 1129,
     1130, 1131, 1132, 1133, 1135, 1136, 1137, 1138, 1139, 1140,
     1141, 1142, 1143, 1079, 1144, 1145, 1119, 1146, 1147, 1148,
     1149, 1150, 1153, 1154, 1156, 1157, 1158, 1162, 1164, 1165,
     1166, 1167, 1168, 1169, 1170, 1172, 1173, 1175, 1176, 1177,
     1179, 1180, 1147, 1181, 1119, 1183, 1184, 1185, 1186, 1188,
     1189, 1190, 1191, 1192, 1194, 1196, 1198, 1199, 1170, 1200,
     1204, 1206, 1208, 1210, 1211,  779,  778,  775,  774,  773,
     1147,  772, 1186,  771,  770,  769,  768,  767,  766,  765,
     1198,  764,  763,  762,  761, 1206, 1170,  760,  758,  757,

      756,  754,  752,  751,  750,  747,  746,  745,  744,  743,
     1186,  741,  740,  739,  738,  737,  736,  735, 1198,  734,
      729,  727,  726, 1206, 1214, 1214, 1214, 1214, 1214, 1214,
     1214, 1214, 1215, 1215, 1215, 1215, 1215, 1215, 1215, 1215,
     1216,  723, 1216, 1216, 1216, 1216, 1217,  722,  721, 1217,
      720,  719, 1217, 1218, 1218, 1218, 1218, 1218, 1218, 1218,
     1218, 1219, 1219, 1219, 1220, 1220, 1220, 1221, 1221, 1222,
     1222, 1223, 1223, 1223, 1223, 1224, 1224, 1224, 1224, 1225,
     1225, 1225, 1225, 1226, 1226, 1226, 1226, 1227, 1227, 1227,
     1227, 1228, 1228, 1228, 1228, 1229, 1229, 1229, 1229, 1230,

     1230, 1230, 1230, 1231, 1231, 1231, 1231, 1232, 1232, 1232,
     1232, 1233, 1233, 1233, 1233, 1234, 1234, 1234, 1234, 1235,
     1235, 1235, 1235, 1236, 1236, 1236, 1236, 1237, 1237, 1237,
     1237,  716,  715,  714,  713,  711,  710,  709,  708,  707,
      704,  702,  701,  700,  699,  698,  697,  696,  695,  694,
      693,  692,  691,  690,  688,  686,  685,  684,  683,  682,
      681,  680,  678,  677,  676,  675,  674,  673,  672,  670,
      669,  668,  667,  666,  665,  664,  663,  662,  661,  660,
      659,  658,  657,  656,  654,  653,  650,  649,  648,  647,
      646,  645,  643,  642,  641,  640,  639,  638,  637,  636,

      633,  632,  631,  630,  629,  628,  627,  626,  622,  621,
      620,  619,  618,  617,  613,  611,  609,  608,  607,  606,
      605,  604,  603,  602,  601,  600,  599,  598,  597,  596,
      594,  593,  592,  591,  589,  588,  587,  586,  584,  582,
      581,  580,  579,  578,  576,  575,  574,  573,  571,  568,
      567,  566,  565,  564,  562,  561,  560,  559,  558,  557,
      556,  555,  554,  553,  552,  551,  550,  549,  547,  545,
      543,  542,  540,  539,  538,  536,  535,  534,  532,  531,
      530,  529,  528,  527,  526,  524,  523,  522,  521,  520,
      519,  516,  515,  512,  511,  509,  508,  501,  500,  493,

      492,  491,  489,  487,  486,  484,  483,  480,  477,  476,
      475,  474,  473,  469,  468,  467,  466,  465,  464,  463,
      462,  461,  460,  459,  457,  456,  454,  453,  452,  451,
      450,  449,  447,  446,  445,  444,  443,  442,  441,  440,
      436,  435,  434,  433,  431,  430,  429,  428,  427,  426,
      425,  423,  422,  421,  420,  419,  418,  416,  415,  414,
      413,  412,  411,  409,  408,  407,  406,  405,  404,  403,
      402,  399,  398,  397,  396,  394,  392,  391,  390,  389,
      387,  386,  385,  384,  383,  381,  380,  378,  377,  376,
      375,  373,  372,  371,  370,  369,  368,  367,  366,  365,

      355,  354,  353,  352,  351,  350,  349,  347,  346,  345,
      343,  342,  341,  340,  337,  336,  335,  333,  332,  331,
      330,  329,  328,  327,  326,  325,  324,  323,  322,  321,
      320,  319,  318,  317,  316,  315,  314,  313,  312,  311,
      310,  308,  303,  301,  300,  298,  297,  296,  295,  294,
      293,  291,  290,  289,  288,  287,  286,  285,  284,  281,
      280,  279,  278,  277,  274,  273,  272,  271,  270,  268,
      267,  266,  265,  263,  262,  261,  259,  258,  257,  256,
      255,  254,  253,  252,  251,  250,  249,  248,  247,  245,
      244,  243,  241,  240,  239,  238,  237,  236,  235,  234,

      233,  232,  231,  228,  227,  216,  207,  206,  205,  204,
      203,  202,  201,  200,  199,  196,  195,  192,  191,  190,
      188,  187,  186,  180,  179,  178,  176,  175,  174,  173,
      172,  171,  168,  166,  163,  159,  158,  157,  156,  154,
      152,  151,  149,  147,  145,  144,  143,  142,  138,  137,
      136,  134,  133,  131,  130,  129,  127,  125,  124,  115,
      114,  110,  109,   99,   98,   97,   90,   85,   73,   68,
       66,   63,   59,   44,   40,   39,   37,   36,   34,   29,
       17,   14,   10,    5, 1213, 1213, 1213, 1213, 1213, 1213,
     1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213,

     1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213,
     1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213,
     1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213,
     1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213,
     1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213,
     1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213,
     1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213, 1213
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "minilexer.l"
/*

Copyright 2007-2022 by

Laboratoire de l'Informatique du Parallelisme,
UMR CNRS - ENS Lyon - UCB Lyon 1 - INRIA 5668,

Laboratoire d'Informatique de Paris 6, equipe PEQUAN,
UPMC Universite Paris 06 - CNRS - UMR 7606 - LIP6, Paris, France,

Laboratoire d'Informatique de Paris 6 - Équipe PEQUAN
Sorbonne Universités
UPMC Univ Paris 06
UMR 7606, LIP6
Boîte Courrier 169
4, place Jussieu
F-75252 Paris Cedex 05
France

and by

Department of Computer Science & Engineering
UAA College of Engineering
University of Alaska Anchorage.

Contributors Ch. Lauter, S. Chevillard

christoph.lauter@christoph-lauter.org
sylvain.chevillard@ens-lyon.org

This software is a computer program whose purpose is to provide an
environment for safe floating-point code development. It is
particularly targeted to the automated implementation of
mathematical floating-point libraries (libm). Amongst other features,
it offers a certified infinity norm, an automatic polynomial
implementer and a fast Remez algorithm.

This software is governed by the CeCILL-C license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL-C
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL-C license and that you accept its terms.

This program is distributed WITHOUT ANY WARRANTY; without even the
implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

*/
#line 70 "minilexer.l"

#include <stdio.h>
#include <string.h>
#include <errno.h>
#include "expression.h"
#include "miniparser.h"
#include "general.h"
#include "chain.h"

#define YY_NO_UNPUT 1
#define YY_NO_INPUT 1

/* Mess with the mallocs used by the lexer */
extern void *parserCalloc(size_t, size_t);
extern void *parserMalloc(size_t);
extern void *parserRealloc(void *, size_t);
extern void parserFree(void *);
#undef malloc
#undef realloc
#undef calloc
#undef free
#define malloc parserMalloc
#define realloc parserRealloc
#define calloc parserCalloc
#define free UNUSED_PARAM(yyscanner); parserFree
/* End of the malloc mess */

/* Mess with fprintf to use sollyaFprintf instead. */
#undef  fprintf
#define fprintf UNUSED_PARAM(yyscanner); sollyaFprintf
/* End of fprintf mess */

/* Mess with getc... and fread to use sollya_getc, sollya_feof, sollya_ferror, sollya_fwrite and sollya_fread instead. */
#undef  getc
#undef  fread
#undef  feof
#undef  ferror
#undef  fwrite
#define getc sollya_getc
#define fread sollya_fread
#define feof sollya_feof
#define ferror sollya_ferror
#define fwrite sollya_fwrite
/* End of getc, feof, ferror, fwrite and fread mess */

/* const mess */
#if defined(const)
#undef const
#endif
/* End of the const mess */

#line 1559 "minilexer.c"

#line 1561 "minilexer.c"

#define INITIAL 0
#define commentstate 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

YYSTYPE * yyget_lval ( yyscan_t yyscanner );

void yyset_lval ( YYSTYPE * yylval_param , yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex \
               (YYSTYPE * yylval_param , yyscan_t yyscanner);

#define YY_DECL int yylex \
               (YYSTYPE * yylval_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yylval = yylval_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 502 "minilexer.l"









#line 1844 "minilexer.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 1214 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1685 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 511 "minilexer.l"
{ miniparserCharactersRead += yyleng;    BEGIN(commentstate); }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 513 "minilexer.l"
{ miniparserCharactersRead += yyleng; BEGIN(INITIAL); }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 515 "minilexer.l"
{ /* Eat up comments */
                  miniparserCharactersRead += yyleng;
                 }
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 519 "minilexer.l"
{ /* Eat up newlines in comments */
                     miniparserCharactersRead += yyleng;
		}
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 525 "minilexer.l"
{  /* Eat up comments */
                    miniparserCharactersRead += yyleng;
                 }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(commentstate):
#line 529 "minilexer.l"
{
                      miniparserEofReached = 1;
                      yyterminate();
                }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 533 "minilexer.l"
{
                                              miniparserCharactersRead += yyleng;
					      constBuffer2 = (char *) safeCalloc(yyleng+1,sizeof(char));
					      if (removeSpaces(constBuffer2,yytext)) {
						printMessage(2,SOLLYA_MSG_SPACES_REMOVED_FROM_CONSTANT_IN_SCIENTIF_NOTAT,"Information: removed spaces in scientific notation constant \"%s\", it will be considered as \"%s\"\n",yytext,constBuffer2);
					      }
					      yylval->value = constBuffer2;
                                              return MIDPOINTCONSTANTTOKEN; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 541 "minilexer.l"
{
                                              miniparserCharactersRead += yyleng;
					      constBuffer2 = (char *) safeCalloc(yyleng+1,sizeof(char));
					      if (removeSpaces(constBuffer2,yytext)) {
						printMessage(2,SOLLYA_MSG_SPACES_REMOVED_FROM_CONSTANT_IN_SCIENTIF_NOTAT,"Information: removed spaces in scientific notation constant \"%s\", it will be considered as \"%s\"\n",yytext,constBuffer2);
					      }
					      yylval->value = constBuffer2;
                                               return CONSTANTTOKEN; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 549 "minilexer.l"
{
                                              miniparserCharactersRead += yyleng;
                                              constBuffer = (char *) safeCalloc(yyleng+1,sizeof(char));
					      strncpy(constBuffer,yytext,yyleng);
					      yylval->value = constBuffer;
                                               return DYADICCONSTANTTOKEN; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 555 "minilexer.l"
{ miniparserCharactersRead += yyleng;
                                              constBuffer = (char *) safeCalloc(yyleng+1,sizeof(char));
					      strncpy(constBuffer,yytext,yyleng);
					      yylval->value = constBuffer;
                                              return HEXADECIMALCONSTANTTOKEN; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 560 "minilexer.l"
{ miniparserCharactersRead += yyleng;
                                              constBuffer = (char *) safeCalloc(yyleng+1,sizeof(char));
					      strncpy(constBuffer,yytext,yyleng);
					      yylval->value = constBuffer;
                                               return HEXCONSTANTTOKEN; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 565 "minilexer.l"
{ miniparserCharactersRead += yyleng;
                                              constBuffer = (char *) safeCalloc(yyleng-1,sizeof(char));
					      strncpy(constBuffer,yytext,yyleng-2);
					      yylval->value = constBuffer;
                                               return BINARYCONSTANTTOKEN; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 571 "minilexer.l"
{ miniparserCharactersRead += yyleng; return PITOKEN; }
	YY_BREAK
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 573 "minilexer.l"
{
                                              miniparserCharactersRead += yyleng;
					      constBuffer = (char *) safeCalloc(yyleng-1,sizeof(char));
					      constBuffer2 = (char *) safeCalloc(yyleng-1,sizeof(char));
					      strncpy(constBuffer2,yytext+1,yyleng-2);
					      demaskString(constBuffer,constBuffer2);
					      safeFree(constBuffer2);
					      yylval->value = constBuffer;
                                               return STRINGTOKEN; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 583 "minilexer.l"
{  miniparserCharactersRead += yyleng; return LPARTOKEN; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 584 "minilexer.l"
{  miniparserCharactersRead += yyleng; return RPARTOKEN; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 585 "minilexer.l"
{  miniparserCharactersRead += yyleng; return LBRACKETTOKEN; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 586 "minilexer.l"
{  miniparserCharactersRead += yyleng; return RBRACKETTOKEN; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 587 "minilexer.l"
{  miniparserCharactersRead += yyleng; return EXCLAMATIONEQUALTOKEN; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 588 "minilexer.l"
{  miniparserCharactersRead += yyleng; return COMPAREEQUALTOKEN; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 589 "minilexer.l"
{  miniparserCharactersRead += yyleng; return EQUALTOKEN; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 590 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ASSIGNEQUALTOKEN; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 591 "minilexer.l"
{  miniparserCharactersRead += yyleng; return COMMATOKEN; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 592 "minilexer.l"
{  miniparserCharactersRead += yyleng; return EXCLAMATIONTOKEN; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 593 "minilexer.l"
{  miniparserCharactersRead += yyleng; return SEMICOLONTOKEN; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 594 "minilexer.l"
{  miniparserCharactersRead += yyleng; return LEFTANGLETOKEN; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 595 "minilexer.l"
{  miniparserCharactersRead += yyleng; return STARLEFTANGLETOKEN; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 596 "minilexer.l"
{  miniparserCharactersRead += yyleng; return RIGHTANGLEUNDERSCORETOKEN; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 597 "minilexer.l"
{  miniparserCharactersRead += yyleng; return RIGHTANGLEDOTTOKEN; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 598 "minilexer.l"
{  miniparserCharactersRead += yyleng; return RIGHTANGLESTARTOKEN; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 599 "minilexer.l"
{  miniparserCharactersRead += yyleng; return RIGHTANGLETOKEN; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 600 "minilexer.l"
{  miniparserCharactersRead += yyleng; return DOTSTOKEN; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 601 "minilexer.l"
{  miniparserCharactersRead += yyleng; return DOTTOKEN; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 602 "minilexer.l"
{  miniparserCharactersRead += yyleng; return QUESTIONMARKTOKEN; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 603 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ANDTOKEN; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 604 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ORTOKEN; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 605 "minilexer.l"
{  miniparserCharactersRead += yyleng; return VERTBARTOKEN; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 606 "minilexer.l"
{  miniparserCharactersRead += yyleng; return VARTOKEN; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 607 "minilexer.l"
{  miniparserCharactersRead += yyleng; return PROCTOKEN; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 608 "minilexer.l"
{  miniparserCharactersRead += yyleng; return PROCEDURETOKEN; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 609 "minilexer.l"
{  miniparserCharactersRead += yyleng; return RETURNTOKEN; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 610 "minilexer.l"
{  miniparserCharactersRead += yyleng; return NOPTOKEN; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 611 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ATTOKEN; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 612 "minilexer.l"
{  miniparserCharactersRead += yyleng; return DOUBLECOLONTOKEN; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 613 "minilexer.l"
{  miniparserCharactersRead += yyleng; return COLONTOKEN; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 614 "minilexer.l"
{  miniparserCharactersRead += yyleng; return DOTCOLONTOKEN; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 615 "minilexer.l"
{  miniparserCharactersRead += yyleng; return COLONDOTTOKEN; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 618 "minilexer.l"
{  miniparserCharactersRead += yyleng; return PLUSTOKEN; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 619 "minilexer.l"
{  miniparserCharactersRead += yyleng; return MINUSTOKEN; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 620 "minilexer.l"
{  miniparserCharactersRead += yyleng; return MULTOKEN; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 621 "minilexer.l"
{  miniparserCharactersRead += yyleng; return DIVTOKEN; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 622 "minilexer.l"
{  miniparserCharactersRead += yyleng; return POWTOKEN; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 624 "minilexer.l"
{  miniparserCharactersRead += yyleng; return SQRTTOKEN; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 625 "minilexer.l"
{  miniparserCharactersRead += yyleng; return EXPTOKEN; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 626 "minilexer.l"
{  miniparserCharactersRead += yyleng; return FREEVARTOKEN; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 627 "minilexer.l"
{  miniparserCharactersRead += yyleng; return LOGTOKEN; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 628 "minilexer.l"
{  miniparserCharactersRead += yyleng; return LOG2TOKEN; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 629 "minilexer.l"
{  miniparserCharactersRead += yyleng; return LOG10TOKEN; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 630 "minilexer.l"
{  miniparserCharactersRead += yyleng; return SINTOKEN; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 631 "minilexer.l"
{  miniparserCharactersRead += yyleng; return COSTOKEN; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 632 "minilexer.l"
{  miniparserCharactersRead += yyleng; return TANTOKEN; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 633 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ASINTOKEN; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 634 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ACOSTOKEN; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 635 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ATANTOKEN; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 636 "minilexer.l"
{  miniparserCharactersRead += yyleng; return SINHTOKEN; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 637 "minilexer.l"
{  miniparserCharactersRead += yyleng; return COSHTOKEN; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 638 "minilexer.l"
{  miniparserCharactersRead += yyleng; return TANHTOKEN; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 639 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ASINHTOKEN; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 640 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ACOSHTOKEN; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 641 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ATANHTOKEN; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 642 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ABSTOKEN; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 643 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ERFTOKEN; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 644 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ERFCTOKEN; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 645 "minilexer.l"
{  miniparserCharactersRead += yyleng; return LOG1PTOKEN; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 646 "minilexer.l"
{  miniparserCharactersRead += yyleng; return EXPM1TOKEN; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 647 "minilexer.l"
{  miniparserCharactersRead += yyleng; return DOUBLETOKEN; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 648 "minilexer.l"
{  miniparserCharactersRead += yyleng; return SINGLETOKEN; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 649 "minilexer.l"
{  miniparserCharactersRead += yyleng; return QUADTOKEN; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 650 "minilexer.l"
{  miniparserCharactersRead += yyleng; return HALFPRECISIONTOKEN; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 651 "minilexer.l"
{  miniparserCharactersRead += yyleng; return DOUBLEDOUBLETOKEN; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 652 "minilexer.l"
{  miniparserCharactersRead += yyleng; return TRIPLEDOUBLETOKEN; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 653 "minilexer.l"
{  miniparserCharactersRead += yyleng; return DOUBLEEXTENDEDTOKEN; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 654 "minilexer.l"
{  miniparserCharactersRead += yyleng; return CEILTOKEN; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 655 "minilexer.l"
{  miniparserCharactersRead += yyleng; return FLOORTOKEN; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 657 "minilexer.l"
{  miniparserCharactersRead += yyleng; return PRECTOKEN; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 658 "minilexer.l"
{  miniparserCharactersRead += yyleng; return POINTSTOKEN; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 659 "minilexer.l"
{  miniparserCharactersRead += yyleng; return DIAMTOKEN; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 660 "minilexer.l"
{  miniparserCharactersRead += yyleng; return DISPLAYTOKEN; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 661 "minilexer.l"
{  miniparserCharactersRead += yyleng; return VERBOSITYTOKEN; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 662 "minilexer.l"
{  miniparserCharactersRead += yyleng; return SHOWMESSAGENUMBERSTOKEN; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 663 "minilexer.l"
{  miniparserCharactersRead += yyleng; return CANONICALTOKEN; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 664 "minilexer.l"
{  miniparserCharactersRead += yyleng; return AUTOSIMPLIFYTOKEN; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 665 "minilexer.l"
{  miniparserCharactersRead += yyleng; return TAYLORRECURSIONSTOKEN; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 666 "minilexer.l"
{  miniparserCharactersRead += yyleng; return TIMINGTOKEN; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 667 "minilexer.l"
{  miniparserCharactersRead += yyleng; return TIMETOKEN; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 668 "minilexer.l"
{  miniparserCharactersRead += yyleng; return FULLPARENTHESESTOKEN; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 669 "minilexer.l"
{  miniparserCharactersRead += yyleng; return MIDPOINTMODETOKEN; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 670 "minilexer.l"
{  miniparserCharactersRead += yyleng; return DIEONERRORMODETOKEN; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 671 "minilexer.l"
{  miniparserCharactersRead += yyleng; return SUPPRESSWARNINGSTOKEN; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 672 "minilexer.l"
{  miniparserCharactersRead += yyleng; return RATIONALMODETOKEN; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 673 "minilexer.l"
{  miniparserCharactersRead += yyleng; return HOPITALRECURSIONSTOKEN; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 675 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ONTOKEN; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 676 "minilexer.l"
{  miniparserCharactersRead += yyleng; return OFFTOKEN; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 677 "minilexer.l"
{  miniparserCharactersRead += yyleng; return DYADICTOKEN; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 678 "minilexer.l"
{  miniparserCharactersRead += yyleng; return POWERSTOKEN; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 679 "minilexer.l"
{  miniparserCharactersRead += yyleng; return BINARYTOKEN; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 680 "minilexer.l"
{  miniparserCharactersRead += yyleng; return HEXADECIMALTOKEN; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 681 "minilexer.l"
{  miniparserCharactersRead += yyleng; return FILETOKEN; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 682 "minilexer.l"
{  miniparserCharactersRead += yyleng; return POSTSCRIPTTOKEN; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 683 "minilexer.l"
{  miniparserCharactersRead += yyleng; return POSTSCRIPTFILETOKEN; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 684 "minilexer.l"
{  miniparserCharactersRead += yyleng; return PERTURBTOKEN; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 685 "minilexer.l"
{  miniparserCharactersRead += yyleng; return MINUSWORDTOKEN; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 686 "minilexer.l"
{  miniparserCharactersRead += yyleng; return PLUSWORDTOKEN; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 687 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ZEROWORDTOKEN; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 688 "minilexer.l"
{  miniparserCharactersRead += yyleng; return NEARESTTOKEN; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 689 "minilexer.l"
{  miniparserCharactersRead += yyleng; return HONORCOEFFPRECTOKEN; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 690 "minilexer.l"
{  miniparserCharactersRead += yyleng; return TRUETOKEN; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 691 "minilexer.l"
{  miniparserCharactersRead += yyleng; return FALSETOKEN; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 692 "minilexer.l"
{  miniparserCharactersRead += yyleng; return DEFAULTTOKEN; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 693 "minilexer.l"
{  miniparserCharactersRead += yyleng; return MATCHTOKEN; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 694 "minilexer.l"
{  miniparserCharactersRead += yyleng; return WITHTOKEN; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 695 "minilexer.l"
{  miniparserCharactersRead += yyleng; return HEADTOKEN; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 696 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ROUNDCORRECTLYTOKEN; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 697 "minilexer.l"
{  miniparserCharactersRead += yyleng; return REVERTTOKEN; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 698 "minilexer.l"
{  miniparserCharactersRead += yyleng; return SORTTOKEN; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 699 "minilexer.l"
{  miniparserCharactersRead += yyleng; return MANTISSATOKEN; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 700 "minilexer.l"
{  miniparserCharactersRead += yyleng; return EXPONENTTOKEN; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 701 "minilexer.l"
{  miniparserCharactersRead += yyleng; return PRECISIONTOKEN; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 702 "minilexer.l"
{  miniparserCharactersRead += yyleng; return TAILTOKEN; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 703 "minilexer.l"
{  miniparserCharactersRead += yyleng; return INFTOKEN; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 704 "minilexer.l"
{  miniparserCharactersRead += yyleng; return MIDTOKEN; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 705 "minilexer.l"
{  miniparserCharactersRead += yyleng; return SUPTOKEN; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 706 "minilexer.l"
{  miniparserCharactersRead += yyleng; return MINTOKEN; }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 707 "minilexer.l"
{  miniparserCharactersRead += yyleng; return MAXTOKEN; }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 708 "minilexer.l"
{  miniparserCharactersRead += yyleng; return READXMLTOKEN; }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 709 "minilexer.l"
{  miniparserCharactersRead += yyleng; return LENGTHTOKEN; }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 710 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ABSOLUTETOKEN; }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 711 "minilexer.l"
{  miniparserCharactersRead += yyleng; return RELATIVETOKEN; }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 712 "minilexer.l"
{  miniparserCharactersRead += yyleng; return DECIMALTOKEN; }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 713 "minilexer.l"
{  miniparserCharactersRead += yyleng; return FIXEDTOKEN; }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 714 "minilexer.l"
{  miniparserCharactersRead += yyleng; return FLOATINGTOKEN; }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 716 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ERRORTOKEN; }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 717 "minilexer.l"
{  miniparserCharactersRead += yyleng; return READFILETOKEN; }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 718 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ISBOUNDTOKEN; }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 720 "minilexer.l"
{
			                        miniparserCharactersRead += yyleng; return FALSEQUITTOKEN;
                                            }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 723 "minilexer.l"
{ miniparserCharactersRead += yyleng; return FALSERESTARTTOKEN; }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 725 "minilexer.l"
{  miniparserCharactersRead += yyleng; return LIBRARYTOKEN; }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 726 "minilexer.l"
{  miniparserCharactersRead += yyleng; return LIBRARYCONSTANTTOKEN; }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 728 "minilexer.l"
{  miniparserCharactersRead += yyleng; return DIFFTOKEN; }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 729 "minilexer.l"
{  miniparserCharactersRead += yyleng; return DIRTYSIMPLIFYTOKEN; }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 730 "minilexer.l"
{  miniparserCharactersRead += yyleng; return REMEZTOKEN; }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 731 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ANNOTATEFUNCTIONTOKEN; }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 732 "minilexer.l"
{  miniparserCharactersRead += yyleng; return FPMINIMAXTOKEN; }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 733 "minilexer.l"
{  miniparserCharactersRead += yyleng; return HORNERTOKEN; }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 734 "minilexer.l"
{  miniparserCharactersRead += yyleng; return EXPANDTOKEN; }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 735 "minilexer.l"
{  miniparserCharactersRead += yyleng; return SIMPLIFYSAFETOKEN; }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 736 "minilexer.l"
{  miniparserCharactersRead += yyleng; return TAYLORTOKEN; }
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 737 "minilexer.l"
{  miniparserCharactersRead += yyleng; return TAYLORFORMTOKEN; }
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 738 "minilexer.l"
{  miniparserCharactersRead += yyleng; return CHEBYSHEVFORMTOKEN; }
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 739 "minilexer.l"
{  miniparserCharactersRead += yyleng; return AUTODIFFTOKEN; }
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 740 "minilexer.l"
{  miniparserCharactersRead += yyleng; return DEGREETOKEN; }
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 741 "minilexer.l"
{  miniparserCharactersRead += yyleng; return NUMERATORTOKEN; }
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 742 "minilexer.l"
{  miniparserCharactersRead += yyleng; return DENOMINATORTOKEN; }
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 743 "minilexer.l"
{  miniparserCharactersRead += yyleng; return SUBSTITUTETOKEN; }
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 744 "minilexer.l"
{  miniparserCharactersRead += yyleng; return COMPOSEPOLYNOMIALSTOKEN; }
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 745 "minilexer.l"
{  miniparserCharactersRead += yyleng; return BEZOUTTOKEN; }
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 746 "minilexer.l"
{  miniparserCharactersRead += yyleng; return COEFFTOKEN; }
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 747 "minilexer.l"
{  miniparserCharactersRead += yyleng; return SUBPOLYTOKEN; }
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 748 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ROUNDCOEFFICIENTSTOKEN; }
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 749 "minilexer.l"
{  miniparserCharactersRead += yyleng; return RATIONALAPPROXTOKEN; }
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 750 "minilexer.l"
{  miniparserCharactersRead += yyleng; return APPROXTOKEN; }
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 751 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ACCURATEINFNORMTOKEN; }
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 752 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ROUNDTOFORMATTOKEN; }
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 753 "minilexer.l"
{  miniparserCharactersRead += yyleng; return EVALUATETOKEN; }
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 755 "minilexer.l"
{  miniparserCharactersRead += yyleng; return PARSETOKEN; }
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 757 "minilexer.l"
{  miniparserCharactersRead += yyleng; return PRINTTOKEN; }
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 758 "minilexer.l"
{  miniparserCharactersRead += yyleng; return SUPPRESSMESSAGETOKEN; }
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 759 "minilexer.l"
{  miniparserCharactersRead += yyleng; return UNSUPPRESSMESSAGETOKEN; }
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 760 "minilexer.l"
{  miniparserCharactersRead += yyleng; return PRINTXMLTOKEN; }
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 761 "minilexer.l"
{  miniparserCharactersRead += yyleng; return EXECUTETOKEN; }
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 762 "minilexer.l"
{  miniparserCharactersRead += yyleng; return PLOTTOKEN; }
	YY_BREAK
case 181:
YY_RULE_SETUP
#line 763 "minilexer.l"
{  miniparserCharactersRead += yyleng; return PRINTHEXATOKEN; }
	YY_BREAK
case 182:
YY_RULE_SETUP
#line 764 "minilexer.l"
{  miniparserCharactersRead += yyleng; return PRINTFLOATTOKEN; }
	YY_BREAK
case 183:
YY_RULE_SETUP
#line 765 "minilexer.l"
{  miniparserCharactersRead += yyleng; return PRINTBINARYTOKEN; }
	YY_BREAK
case 184:
YY_RULE_SETUP
#line 766 "minilexer.l"
{  miniparserCharactersRead += yyleng; return PRINTEXPANSIONTOKEN; }
	YY_BREAK
case 185:
YY_RULE_SETUP
#line 767 "minilexer.l"
{  miniparserCharactersRead += yyleng; return BASHEXECUTETOKEN; }
	YY_BREAK
case 186:
YY_RULE_SETUP
#line 768 "minilexer.l"
{  miniparserCharactersRead += yyleng; return BASHEVALUATETOKEN; }
	YY_BREAK
case 187:
YY_RULE_SETUP
#line 769 "minilexer.l"
{  miniparserCharactersRead += yyleng; return GETSUPPRESSEDMESSAGESTOKEN; }
	YY_BREAK
case 188:
YY_RULE_SETUP
#line 770 "minilexer.l"
{  miniparserCharactersRead += yyleng; return GETBACKTRACETOKEN; }
	YY_BREAK
case 189:
YY_RULE_SETUP
#line 771 "minilexer.l"
{  miniparserCharactersRead += yyleng; return EXTERNALPLOTTOKEN; }
	YY_BREAK
case 190:
YY_RULE_SETUP
#line 772 "minilexer.l"
{  miniparserCharactersRead += yyleng; return WRITETOKEN; }
	YY_BREAK
case 191:
YY_RULE_SETUP
#line 773 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ASCIIPLOTTOKEN; }
	YY_BREAK
case 192:
YY_RULE_SETUP
#line 774 "minilexer.l"
{  miniparserCharactersRead += yyleng; return RENAMETOKEN; }
	YY_BREAK
case 193:
YY_RULE_SETUP
#line 775 "minilexer.l"
{  miniparserCharactersRead += yyleng; return OBJECTNAMETOKEN; }
	YY_BREAK
case 194:
YY_RULE_SETUP
#line 776 "minilexer.l"
{  miniparserCharactersRead += yyleng; return BINDTOKEN; }
	YY_BREAK
case 195:
YY_RULE_SETUP
#line 779 "minilexer.l"
{  miniparserCharactersRead += yyleng; return INFNORMTOKEN; }
	YY_BREAK
case 196:
YY_RULE_SETUP
#line 780 "minilexer.l"
{  miniparserCharactersRead += yyleng; return SUPNORMTOKEN; }
	YY_BREAK
case 197:
YY_RULE_SETUP
#line 781 "minilexer.l"
{  miniparserCharactersRead += yyleng; return FINDZEROSTOKEN; }
	YY_BREAK
case 198:
YY_RULE_SETUP
#line 782 "minilexer.l"
{  miniparserCharactersRead += yyleng; return FPFINDZEROSTOKEN; }
	YY_BREAK
case 199:
YY_RULE_SETUP
#line 783 "minilexer.l"
{  miniparserCharactersRead += yyleng; return DIRTYINFNORMTOKEN; }
	YY_BREAK
case 200:
YY_RULE_SETUP
#line 784 "minilexer.l"
{  miniparserCharactersRead += yyleng; return GCDTOKEN; }
	YY_BREAK
case 201:
YY_RULE_SETUP
#line 785 "minilexer.l"
{  miniparserCharactersRead += yyleng; return EUCLDIVTOKEN; }
	YY_BREAK
case 202:
YY_RULE_SETUP
#line 786 "minilexer.l"
{  miniparserCharactersRead += yyleng; return EUCLMODTOKEN; }
	YY_BREAK
case 203:
YY_RULE_SETUP
#line 787 "minilexer.l"
{  miniparserCharactersRead += yyleng; return NUMBERROOTSTOKEN; }
	YY_BREAK
case 204:
YY_RULE_SETUP
#line 788 "minilexer.l"
{  miniparserCharactersRead += yyleng; return INTEGRALTOKEN; }
	YY_BREAK
case 205:
YY_RULE_SETUP
#line 789 "minilexer.l"
{  miniparserCharactersRead += yyleng; return DIRTYINTEGRALTOKEN; }
	YY_BREAK
case 206:
YY_RULE_SETUP
#line 790 "minilexer.l"
{  miniparserCharactersRead += yyleng; return WORSTCASETOKEN; }
	YY_BREAK
case 207:
YY_RULE_SETUP
#line 791 "minilexer.l"
{  miniparserCharactersRead += yyleng; return IMPLEMENTPOLYTOKEN; }
	YY_BREAK
case 208:
YY_RULE_SETUP
#line 792 "minilexer.l"
{  miniparserCharactersRead += yyleng; return IMPLEMENTCONSTTOKEN; }
	YY_BREAK
case 209:
YY_RULE_SETUP
#line 793 "minilexer.l"
{  miniparserCharactersRead += yyleng; return INTERPOLATETOKEN; }
	YY_BREAK
case 210:
YY_RULE_SETUP
#line 794 "minilexer.l"
{  miniparserCharactersRead += yyleng; return CHECKINFNORMTOKEN; }
	YY_BREAK
case 211:
YY_RULE_SETUP
#line 795 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ZERODENOMINATORSTOKEN; }
	YY_BREAK
case 212:
YY_RULE_SETUP
#line 796 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ISEVALUABLETOKEN; }
	YY_BREAK
case 213:
YY_RULE_SETUP
#line 797 "minilexer.l"
{  miniparserCharactersRead += yyleng; return SEARCHGALTOKEN; }
	YY_BREAK
case 214:
YY_RULE_SETUP
#line 798 "minilexer.l"
{  miniparserCharactersRead += yyleng; return GUESSDEGREETOKEN; }
	YY_BREAK
case 215:
YY_RULE_SETUP
#line 799 "minilexer.l"
{  miniparserCharactersRead += yyleng; return DIRTYFINDZEROSTOKEN; }
	YY_BREAK
case 216:
YY_RULE_SETUP
#line 801 "minilexer.l"
{  miniparserCharactersRead += yyleng; return IFTOKEN; }
	YY_BREAK
case 217:
YY_RULE_SETUP
#line 802 "minilexer.l"
{  miniparserCharactersRead += yyleng; return THENTOKEN; }
	YY_BREAK
case 218:
YY_RULE_SETUP
#line 803 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ELSETOKEN; }
	YY_BREAK
case 219:
YY_RULE_SETUP
#line 804 "minilexer.l"
{  miniparserCharactersRead += yyleng; return FORTOKEN; }
	YY_BREAK
case 220:
YY_RULE_SETUP
#line 805 "minilexer.l"
{  miniparserCharactersRead += yyleng; return INTOKEN; }
	YY_BREAK
case 221:
YY_RULE_SETUP
#line 806 "minilexer.l"
{  miniparserCharactersRead += yyleng; return FROMTOKEN; }
	YY_BREAK
case 222:
YY_RULE_SETUP
#line 807 "minilexer.l"
{  miniparserCharactersRead += yyleng; return TOTOKEN; }
	YY_BREAK
case 223:
YY_RULE_SETUP
#line 808 "minilexer.l"
{  miniparserCharactersRead += yyleng; return BYTOKEN; }
	YY_BREAK
case 224:
YY_RULE_SETUP
#line 809 "minilexer.l"
{  miniparserCharactersRead += yyleng; return DOTOKEN; }
	YY_BREAK
case 225:
YY_RULE_SETUP
#line 810 "minilexer.l"
{  miniparserCharactersRead += yyleng; return BEGINTOKEN; }
	YY_BREAK
case 226:
YY_RULE_SETUP
#line 811 "minilexer.l"
{  miniparserCharactersRead += yyleng; return ENDTOKEN; }
	YY_BREAK
case 227:
YY_RULE_SETUP
#line 812 "minilexer.l"
{  miniparserCharactersRead += yyleng; return LEFTCURLYBRACETOKEN; }
	YY_BREAK
case 228:
YY_RULE_SETUP
#line 813 "minilexer.l"
{  miniparserCharactersRead += yyleng; return RIGHTCURLYBRACETOKEN; }
	YY_BREAK
case 229:
YY_RULE_SETUP
#line 814 "minilexer.l"
{  miniparserCharactersRead += yyleng; return WHILETOKEN; }
	YY_BREAK
case 230:
YY_RULE_SETUP
#line 816 "minilexer.l"
{  miniparserCharactersRead += yyleng; return EXTERNALPROCTOKEN; }
	YY_BREAK
case 231:
YY_RULE_SETUP
#line 817 "minilexer.l"
{  miniparserCharactersRead += yyleng; return EXTERNALDATATOKEN; }
	YY_BREAK
case 232:
YY_RULE_SETUP
#line 818 "minilexer.l"
{  miniparserCharactersRead += yyleng; return VOIDTOKEN; }
	YY_BREAK
case 233:
YY_RULE_SETUP
#line 819 "minilexer.l"
{  miniparserCharactersRead += yyleng; return CONSTANTTYPETOKEN; }
	YY_BREAK
case 234:
YY_RULE_SETUP
#line 820 "minilexer.l"
{  miniparserCharactersRead += yyleng; return FUNCTIONTOKEN; }
	YY_BREAK
case 235:
YY_RULE_SETUP
#line 821 "minilexer.l"
{  miniparserCharactersRead += yyleng; return OBJECTTOKEN; }
	YY_BREAK
case 236:
YY_RULE_SETUP
#line 822 "minilexer.l"
{  miniparserCharactersRead += yyleng; return RANGETOKEN; }
	YY_BREAK
case 237:
YY_RULE_SETUP
#line 823 "minilexer.l"
{  miniparserCharactersRead += yyleng; return INTEGERTOKEN; }
	YY_BREAK
case 238:
YY_RULE_SETUP
#line 824 "minilexer.l"
{  miniparserCharactersRead += yyleng; return STRINGTYPETOKEN; }
	YY_BREAK
case 239:
YY_RULE_SETUP
#line 825 "minilexer.l"
{  miniparserCharactersRead += yyleng; return BOOLEANTOKEN; }
	YY_BREAK
case 240:
YY_RULE_SETUP
#line 826 "minilexer.l"
{  miniparserCharactersRead += yyleng; return LISTTOKEN; }
	YY_BREAK
case 241:
YY_RULE_SETUP
#line 827 "minilexer.l"
{  miniparserCharactersRead += yyleng; return OFTOKEN; }
	YY_BREAK
case 242:
YY_RULE_SETUP
#line 831 "minilexer.l"
{ /* Eat up spaces and tabulators */
                  miniparserCharactersRead += yyleng;
		}
	YY_BREAK
case 243:
YY_RULE_SETUP
#line 835 "minilexer.l"
{ /* Eat up carriage return for compatibility with DOS-like systems */
                  miniparserCharactersRead += yyleng;
                }
	YY_BREAK
case 244:
/* rule 244 can match eol */
YY_RULE_SETUP
#line 839 "minilexer.l"
{
                  miniparserCharactersRead += yyleng;
		}
	YY_BREAK
case 245:
YY_RULE_SETUP
#line 843 "minilexer.l"
{ miniparserCharactersRead += yyleng;
                                              constBuffer = (char *) safeCalloc(yyleng+1,sizeof(char));
					      strncpy(constBuffer,yytext,yyleng);
					      yylval->value = constBuffer;
					       return IDENTIFIERTOKEN; }
	YY_BREAK
case 246:
YY_RULE_SETUP
#line 850 "minilexer.l"
{ /* otherwise */
                        miniparserCharactersRead += yyleng;
			printMessage(1,SOLLYA_MSG_A_CHARACTER_COULD_NOT_BE_RECOGNIZED,"The character \"%s\" cannot be recognized. Will ignore it.\n",
				yytext);
}
	YY_BREAK
case 247:
YY_RULE_SETUP
#line 856 "minilexer.l"
ECHO;
	YY_BREAK
#line 3209 "minilexer.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 1214 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	char *yy_cp = yyg->yy_c_buf_p;

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 1214 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 1213);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

	b->yy_is_interactive = 1;

	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

#define YYTABLES_NAME "yytables"

#line 856 "minilexer.l"


void *startMiniparser(void *scanner, char *str) {
  YY_BUFFER_STATE buf;

  miniparserSemicolonAtEnd = 0;
  miniparserEofReached = 0;
  miniparserCharactersRead = 0;
  buf = miniyy_scan_string(str, scanner);
  miniyy_switch_to_buffer(buf, scanner);

  return NULL;
}

void endMiniparser(void *buf, void *scanner) {
  miniyy_delete_buffer(buf, scanner);
}

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
        UNUSED_PARAM(yyscanner);
        return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
        /* The cast to (char *) in the following accommodates both
         * implementations that use char* generic pointers, and those
         * that use void* generic pointers.  It works with the latter
         * because both ANSI C and C++ allow castless assignment from
         * any pointer type to void*, and deal with argument conversions
         * as though doing an assignment.
         */
        UNUSED_PARAM(yyscanner);
        return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
        UNUSED_PARAM(yyscanner);
        free( (char *) ptr );   /* see yyrealloc() for (char *) cast */
}

